@@ -151,7 +151,7 @@ void v_shoall()
 #if	BSD43 | ULTRIX | DECOSF
 	daepresent = daepres (Queuefile);
 #else
-#if	HPUX | SGI  | SOLARIS | SYS52 | IBMRS 
+#if	HPUX | SGI  | SOLARIS | SYS52 | IBMRS | LINUX
 	daepresent = daepres();
 #else
 BAD SYSTEM TYPE
@@ -328,7 +328,7 @@ void v_sholongque()
 #if	BSD43 | ULTRIX | DECOSF
 	daepresent = daepres (Queuefile);
 #else
-#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS 
+#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
 	daepresent = daepres();
 #else
 BAD SYSTEM TYPE
@@ -646,7 +646,7 @@ void v_shoque()
 #if	BSD43 | ULTRIX | DECOSF
 	daepresent = daepres (Queuefile);
 #else
-#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS 
+#if	HPUX | SGI | SOLARIS | SYS52 | IBMRS | LINUX
 	daepresent = daepres();
 #else
 BAD SYSTEM TYPE
